*******************
Authors and Credits
*******************

Astropy Project Coordinators
============================

* Tom Aldcroft
* Kelle Cruz
* Thomas Robitaille
* Erik Tollerud


Core Package Contributors
=========================

* Ryan Abernathey
* Shailesh Ahuja
* Tom Aldcroft
* Anne Archibald
* Cristian Ardelean
* Tomas Babej
* Matteo Bachetti
* Steven Bamford
* Kyle Barbary
* Geert Barentsen
* Pauline Barmby
* Paul Barrett
* Andreas Baumbach
* Chris Beaumont
* Daniel Bell
* Elijah Bernstein-Cooper
* Kristin Berry
* Edward Betts
* Mavani Bhautik
* Francesco Biscani
* Thompson Le Blanc
* Christopher Bonnett
* Joseph Jon Booker
* Médéric Boquien
* Azalee Bostroem
* Luke G. Bouma
* Matthew Bourque
* Larry Bradley
* Gustavo Bragança
* Gabriel Brammer
* Erik M. Bray
* Eli Bressert
* Matthew Brett
* Hannes Breytenbach
* Hugo Buddelmeijer
* Doug Burke
* Giorgio Calderone
* Mihai Cara
* Patti Carroll
* Mabry Cervin
* Pritish Chakraborty
* Sourabh Cheedella
* Alex Conley
* Jean Connelly
* Simon Conseil
* Ryan Cooke
* Yannick Copin
* Michele Costa
* Matthew Craig
* Steve Crawford
* Devin Crichton
* Neil Crighton
* Robert Cross
* Kelle Cruz
* Dan P. Cunningham
* Ritwick DSouza
* Daniel Datsev
* Matt Davis
* James Dearman
* Christoph Deil
* Nadia Dencheva
* Eric Depagne
* Jörg Dietrich
* Axel Donath
* Bili Dong
* Michael Droettboom
* Zach Edwards
* Jonathan Eisenhamer
* Thomas Erben
* Henry Ferguson
* Leonardo Ferreira
* Tyler Finethy
* Jonathan Foster
* Ryan Fox
* Lehman Garrison
* Simon Gibbons
* Adam Ginsburg
* Christoph Gohlke
* Danny Goldstein
* Ralf Gommers
* J. Goutin
* Johnny Greco
* Perry Greenfield
* Dylan Gregersen
* Austen Groener
* Frédéric Grollier
* Karan Grover
* Kevin Gullikson
* Hans Moritz Günther
* Chris Hanley
* Alex Hagen
* Andrew Hearin
* Christian Hettlage
* Paul Hirst
* Moataz Hisham
* Michael Hoenig
* Emma Hogan
* Derek Homeier
* Anthony Horton
* JC Hsu
* Griffin Hosseinzadeh
* Lingyi Hu
* Jurien Huisman
* Joe Hunkeler
* Anchit Jain
* VSN Reddy Janga
* Eric Jeschke
* Graham Kanarek
* Anirudh Katipally
* Sarah Kendrew
* Marten van Kerkwijk
* Nicholas S. Kern
* Wolfgang Kerzendorf
* Lennard Kiehl
* Rashid Khan
* Aleh Khvalko
* David Kirkby
* Dominik Klaes
* Tom Kooij
* Kacper Kowalik
* Roban Hultman Kramer
* Aniket Kulkarni
* Amit Kumar
* Arie Kurniawan
* Arne de Laat
* Antony Lee
* Daniel Lenz
* Kieran Leschinski
* Simon Liedtke
* Pey Lian Lim
* Stuart Littlefair
* Joseph Long
* Joe Lyman
* Jerry Ma
* Duncan Macleod
* Michele Mastropietro
* Curtis McCully
* Vinayak Mehta
* Aaron Meisner
* Mikhail Minin
* Serge Montagnac
* José Sabater Montes
* Francesco Montesano
* Brett Morris
* Michael Mueller
* Stuart Mumford
* Demitri Muna
* Nick Murphy
* Prasanth Nair
* Stefan Nelson
* Giang Nguyen
* Bogdan Nicula
* Al Niessner
* Joe Philip Ninan
* Asra Nizami
* Bryce Nordgren
* Sigurd Næss
* Maximilian Nöthe
* Sara Ogaz
* Georgiana Ogrean
* Semyeong Oh
* Miruna Oprescu
* Carl Osterwisch
* Luigi Paioro
* David M. Palmer
* Asish Panda
* John Parejko
* Madhura Parikh
* Neil Parley
* Sergio Pascual
* Pratik Patel
* Rohit Patil
* Aarya Patil
* Ray Plante
* Adele Plunkett
* Orion Poplawski
* Joanna Power
* Adrian Price-Whelan
* J. Xavier Prochaska
* David Pérez-Suárez
* Tanuj Rastogi
* Thomas Robitaille
* Juan Luis Cano Rodríguez
* Evert Rol
* Alex Rudy
* Joseph Ryan
* Eloy Salinas
* Gerrit Schellenberger
* Michael Seifert
* Srikrishna Sekhar
* Mathieu Servillat
* Helen Sherwood-Taylor
* David Shiga
* Albert Y. Shih
* David Shupe
* Jonathan Sick
* Max Silbiger
* Bernie Simon
* Sudheesh Singanamalla
* Leo Singer
* Brigitta Sipocz
* Paul Sladen
* Kevin Sooley
* Shivan Sornarajah
* Shantanu Srivastava
* Ole Streicher
* Matej Stuchlik
* Bernardo Sulzbach
* Vatsala Swaroop
* Esteban Pardo Sánchez
* James Taylor
* Jeff Taylor
* Mark Taylor
* Kirill Tchernyshyov
* Régis Terrier
* Víctor Terrón
* Scott Thomas
* Erik Tollerud
* Matthew Turk
* James Turner
* Miguel de Val-Borro
* Jake VanderPlas
* Alex de la Vega
* Sam Verstocken
* Zé Vinicius
* Karl Vyhmeister
* Lisa Walter
* Laura Watkins
* Benjamin Alan Weaver
* Jonathan Whitmore
* Julien Woillez
* Maneesh Yadav
* Víctor Zabalza


Other Credits
=============

* Kyle Barbary for designing the Astropy logos and documentation themes.
* Andrew Pontzen and the `pynbody <https://github.com/pynbody/pynbody>`_ team
  (For code that grew into :mod:`astropy.units`)
* Everyone on the `astropy-dev mailing list`_ and the `Astropy mailing list`_
  for contributing to many discussions and decisions!

(If you have contributed to the ``astropy`` core package and your name is missing,
please send an email to the coordinators, or
`open a pull request for this page <https://github.com/astropy/astropy/edit/master/docs/credits.rst>`_
in the `astropy repository <https://github.com/astropy/astropy>`_)

For how to acknowledge Astropy, please see `the Acknowledging or Citing Astropy page <http://www.astropy.org/acknowledging.html>`_.
